@@ -31,14 +31,14 @@ class ScoringFunctionComponentNameEnum:
     SA_SCORE = "sa_score"
     AZDOCK = "azdock"
     AZ_LOGD74_PIP = "azlogd74"
-    CACO2_INTR_PIP = "intrcaco2"
+    CACO2_INTR_PIP = "caco2-intrinsic-papp"
     CACO2_EFFLUX_PIP = "caco2-efflux"
     HH_CLINT_PIP = "hh-clint"
     HLM_CLINT_PIP = "hlm-clint"
     RH_CLINT_PIP = "rh-clint"
     SOLUBILITY_DD_PIP = "solubility-dd"
     HERG_PIP = "herg"
-    KPUU_PIP = "kpuu-brain"
+    KPUU_PIP = "rat-kpuu-brain"
     RAT_PK_PIP = "rat-pk"
     CLAB_TOP_20 = "clab_top_20"
     RA_SCORE = "rascore"
